﻿using System;
using System.ComponentModel;
using System.Runtime.CompilerServices;

namespace SampleeGrid
{
    class StoreLists : INotifyPropertyChanged
    {
        #region PRIVATE MEMBERS
        private bool addtoCart;
        private string category;
        private double quantity;
        private int discount;
        private double price;
        private DateTime publishedDate;
        private string reviewLink;
        private string reviewText;
        private string name;
        #endregion

        #region PUBLIC MEMBERS

        /// <summary>
        /// Gets or sets a Cart
        /// </summary>
        /// <value>
        ///   <c>true</c> if cart; otherwise, <c>false</c>.
        /// </value>
        public bool Cart
        {
            get
            {
                return addtoCart;
            }
            set
            {
                addtoCart = value;
                OnPropertyChanged();
            }
        }

        /// <summary>
        /// Gets or sets Category.
        /// </summary>
        /// <value>
        /// The category.
        /// </value>
        public string Category
        {
            get
            {
                return category;
            }
            set
            {
                category = value;
                OnPropertyChanged();
            }
        }

        /// <summary>
        /// Gets or sets the Quantity.
        /// </summary>
        /// <value>
        /// The quantity.
        /// </value>
        public double Quantity
        {
            get
            {
                return quantity;
            }
            set
            {
                quantity = value;
                OnPropertyChanged();
            }
        }

        /// <summary>
        /// Gets or sets the Discount.
        /// </summary>
        /// <value>
        /// The discount.
        /// </value>
        public int Discount
        {
            get
            {
                return discount;
            }
            set
            {
                discount = value;
                OnPropertyChanged();
            }
        }

        /// <summary>
        /// Gets or sets the Price.
        /// </summary>
        /// <value>
        /// The price.
        /// </value>
        public double Price
        {
            get
            {
                return price;
            }
            set
            {
                price = value;
                OnPropertyChanged();
            }
        }

        /// <summary>
        /// Gets or sets the Published Date.
        /// </summary>
        /// <value>
        /// The published date.
        /// </value>
        public DateTime PublishedDate
        {
            get
            {
                return publishedDate;
            }
            set
            {
                publishedDate = value;
                OnPropertyChanged();
            }
        }

        /// <summary>
        /// Gets or sets the Navigate URI.
        /// </summary>
        /// <value>
        /// The navigate URI.
        /// </value>
        public string NavigateURI
        {
            get
            {
                return reviewLink;
            }
            set
            {
                reviewLink = value;
                OnPropertyChanged();
            }
        }

        /// <summary>
        /// Gets or sets the Navigate Text.
        /// </summary>
        /// <value>
        /// The navigate text.
        /// </value>
        public string NavigateText
        {
            get
            {
                return reviewText;
            }
            set
            {
                reviewText = value;
                OnPropertyChanged();
            }
        }

        /// <summary>
        /// Gets or sets the title.
        /// </summary>
        /// <value>
        /// The title.
        /// </value>
        public string Title
        {
            get
            {
                return name;
            }
            set
            {
                name = value;
                OnPropertyChanged();
            }
        }

        #endregion

        #region CTOR
        /// <summary>
        /// Initializes a new instance of the <see cref="StoreList"/> class.
        /// </summary>
        public StoreLists(bool _addtoCart, string _category, int _quantity, int _discount, double _price, DateTime _publishedDate, string _reviewLink, string _reviewText, string _name)
        {
            addtoCart = _addtoCart;
            category = _category;
            quantity = _quantity;
            discount = _discount;
            price = _price;
            publishedDate = _publishedDate;
            reviewLink = _reviewLink;
            reviewText = _reviewText;
            name = _name;
        }
        #endregion

        #region INOTIFYPROPERTYCHANGED
        public event PropertyChangedEventHandler PropertyChanged;

        protected virtual void OnPropertyChanged([CallerMemberName] string propertyName = null)
        {
            var handler = PropertyChanged;
            if (handler != null)
                handler(this, new PropertyChangedEventArgs(propertyName));
        }
        #endregion
    }
}